/*
	This file is part of Faster Application Manager.

	Faster Application Manager is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Faster Application Manager is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Faster Application Manager.  If not, see <http://www.gnu.org/licenses/>.

	(C) Heikki Holstila 2010
*/

#ifndef PACKAGEVIEW_H
#define PACKAGEVIEW_H

#include <QtGui>
#include <QMainWindow>
#include "mainwindow.h"
#include "package.h"

namespace Ui {
    class PackageView;
}

class MainWindow;
class AptInterface;
class Package;
class dimmer;
class KeyEventGrabber;

enum UserRoles { UserRoleName=Qt::UserRole, UserRoleVersion, UserRoleDescShort,
				 UserRoleMarked, UserRoleInstalled, UserRoleUpgradeable, UserRoleAvailVersion,
				 UserRoleCurrentStatFilter };


class PackageListWidgetItem : public QListWidgetItem
{
public:
	PackageListWidgetItem(Package* p_, QString name_);

	Package* package() { return iPackage; }

private:
	Package* iPackage;
};


class ListItemDelegate : public QStyledItemDelegate
{
public:
	ListItemDelegate(QObject *parent=0) : QStyledItemDelegate (parent) { }

	void paint (QPainter* painter, const QStyleOptionViewItem& option, const QModelIndex& index) const;
	QSize sizeHint(const QStyleOptionViewItem& option, const QModelIndex& index) const;
	void loadIcons();

private:
	QPixmap iDefaultIcon;
	QPixmap iIconPkgInstall;
	QPixmap iIconPkgUpgrade;
	QPixmap iIconPkgRemove;
	QPixmap iIconPkgNoOpInstalled;
	QPixmap iIconPkgNoOpNotInstalled;
	QPixmap iIconPkgNoOpInstalledUpgradeable;
};


class PackageView : public QMainWindow
{
    Q_OBJECT

public:

	enum sortOrder { SortAlpha, SortSizeDesc, SortDateDesc };

    explicit PackageView(QWidget *parent = 0);
    ~PackageView();
	void openWin();
	void resizeEvent(QResizeEvent* event);
	void setAptInterface(AAptInterface* a_) { iAptInterface=a_; }
	dimmer* mydimmer() { return iDimmer; }
	void disableMenu();
	void enableMenu();
	void setStatFilter(Package::packageStatus f_);
	void clearSelections();
	void setSearchText(QString text);

#ifdef Q_WS_MAEMO_5		// workaround for buggy Qt autorotation
	void show() {
		if( !isVisible() ) {
			QRect r = dynamic_cast<QMainWindow*>(this->parent())->rect();
			if(r.width() < r.height()) {
				this->setAttribute(Qt::WA_Maemo5PortraitOrientation);
			}
			else {
				if( dynamic_cast<QMainWindow*>(this->parent())->testAttribute( Qt::WA_Maemo5AutoOrientation ) ) {
					this->setAttribute( Qt::WA_Maemo5AutoOrientation );
				} else {
					this->setAttribute( Qt::WA_Maemo5LandscapeOrientation );
				}
				this->setAttribute(Qt::WA_Maemo5StackedWindow);
				this->setWindowFlags(Qt::Window);
			}
		}
		QMainWindow::show();
	}
#endif

public slots:
	void orientationChanged();
	void on_actionSearch_triggered();

protected:
    void changeEvent(QEvent *e);
	AAptInterface* iAptInterface;
	//MainWindow::operation iOperation;
	void closeEvent(QCloseEvent *event);

private:
	bool doFilterCategory(Package* pkg);
	QString generateSortString(Package* pkg);
	void addListItem(Package* pkg_, QString listname_);
	void updateLabel(void);
	void resetWindow();
	void clearSearch();

    Ui::PackageView *ui;
	MainWindow* iMainWindow;
	QBoxLayout* iPkgLayout;
	dimmer* iDimmer;
	QLabel* iListCoverLabel;

	QStringList iCatFilterLabels;
	QStringList iCatFilterStrings;
	int iSelectedCatFilter;
	int iDefaultCatFilter;
	static const int CatFilterAllMarked = 0;
	static const int CatFilterAllUser = 1;
	static const int CatFilterBlacklisted = 16;

	QStringList iStatFilterLabels;
	int iSelectedStatFilter;
	sortOrder iSortOrder;
	bool iSortNoticeShown;

	QList<Package*> iSearchResults;
	QString iPrevSearchText;
	KeyEventGrabber* iKeyFilter;

	int iPackagesEmptySort;

private slots:
	void on_actionRestore_all_triggered();
 void on_actionSave_selections_triggered();
	void on_actionLoad_selections_triggered();
	void on_btn_Sort_clicked();
	void on_actionView_log_triggered();
	void on_actionUpgrade_all_triggered();
	void on_lineEdit_textEdited(QString );
	void on_btn_searchClose_clicked();
	void on_actionHelp_triggered();
	void on_btn_StatusFilter_clicked();
	void on_btn_CategoryFilter_clicked();
	void on_listWidget_itemClicked(QListWidgetItem* item);
	void on_actionClear_selections_triggered();
	void on_btn_Commit_clicked();
};


class KeyEventGrabber : public QObject
{
	Q_OBJECT
public:
	KeyEventGrabber(QObject* parent = 0);

protected:
	bool eventFilter(QObject *obj, QEvent *event);

};


#endif // PACKAGEVIEW_H
